==> zeo-collect-0.2.4.tgz: package/android/src/main/java/com/zeocollect/ZeoCollectModule.java <==
package com.zeocollect;

import android.util.Log;

import androidx.annotation.NonNull;

import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.module.annotations.ReactModule;
import com.zeotap.collect.Collect;
import com.zeotap.collect.CollectOptions;

import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;

@ReactModule(name = ZeoCollectModule.NAME)
public class ZeoCollectModule extends ReactContextBaseJavaModule {
    public static final String NAME = "ZeoCollect";
    CollectOptions.Builder builder;
    Collect collect;
    ReactApplicationContext mReactContext;

    public ZeoCollectModule(ReactApplicationContext reactContext) {
        super(reactContext);
        mReactContext = reactContext;
    }

    @ReactMethod
    public void initalizeBySettingOptions(ReadableMap rawOptions) {
        builder = CollectOptions.builder(mReactContext);
        HashMap<String, Object> clientOptions = rawOptions.toHashMap();
        if (clientOptions.get("logging") != null && clientOptions.get("logging") instanceof Boolean) {
            builder = builder.enableLogging((Boolean) clientOptions.get("logging"));
        }
        if (clientOptions.get("batch_size") != null && !Objects.equals(clientOptions.get("batch_size"), "") && clientOptions.get("batch_size") instanceof Integer) {
            builder = builder.uploadBatchSize((Integer) clientOptions.get("batch_size"));
        }
        if (clientOptions.get("optout") != null && clientOptions.get("optout")  instanceof Boolean) {
            builder = builder.optOut((Boolean) clientOptions.get("optout"));
        }
        if (clientOptions.get("android_write_key") != null && !Objects.equals(clientOptions.get("write_key"), "") && clientOptions.get("write_key") instanceof String) {
            builder = builder.credential((String) clientOptions.get("write_key"));
        }
        if (clientOptions.get("service_interval") != null && !Objects.equals(clientOptions.get("service_interval"), "") && clientOptions.get("service_interval") instanceof Integer)  {
            builder = builder.serviceUploadInterval((Integer) clientOptions.get("service_interval"));
        }
        if (clientOptions.get("useConsent") != null && clientOptions.get("useConsent") instanceof Boolean) {
            builder = builder.useConsent((Boolean) clientOptions.get("useConsent"));
        }
        if (clientOptions.get("maxCacheSize") != null && !Objects.equals(clientOptions.get("maxCacheSize"), "") && clientOptions.get("maxCacheSize") instanceof Integer) {
            builder = builder.maxCacheSize((Integer) clientOptions.get("maxCacheSize"));
        }
        if (clientOptions.get("userCountry") != null && !Objects.equals(clientOptions.get("userCountry"), "") && clientOptions.get("userCountry") instanceof String) {
            builder = builder.userCountry((String) clientOptions.get("userCountry"));
        }
        if (clientOptions.get("checkForCMP") != null && clientOptions.get("checkForCMP") instanceof Boolean) {
            builder = builder.checkForCMP((Boolean) clientOptions.get("checkForCMP"));
        }
        if (clientOptions.get("purposesForTracking") != null && clientOptions.get("purposesForTracking") instanceof List) {
            builder = builder.purposesForTracking((ArrayList<Integer>) clientOptions.get("purposesForTracking"));
        }
        if (clientOptions.get("purposesForIdentify") != null && clientOptions.get("purposesForIdentify") instanceof List) {
            builder = builder.purposesForTracking((ArrayList<Integer>) clientOptions.get("purposesForIdentify"));
        }
        if (clientOptions.get("areIdentitiesHashed") != null && clientOptions.get("areIdentitiesHashed") instanceof Boolean) {
            builder = builder.areIdentitiesHashed((Boolean) clientOptions.get("areIdentitiesHashed"));
            if (clientOptions.get("hashIdentities") != null && clientOptions.get("hashIdentities") instanceof Boolean) {
                builder = builder.hashIdentities((Boolean) clientOptions.get("hashIdentities"));
            }
        }
//        if (clientOptions.get("checkZeotapVendorConsent") != null && clientOptions.get("checkZeotapVendorConsent") instanceof Boolean) {
//            builder = builder.checkZeotapVendorConsent((Boolean) clientOptions.get("checkZeotapVendorConsent"));
//        }
//        Log.d("teest", "collect before init" + collect.getClass().toString());
        Log.d("teest", collect == null ? "collect before init, collect is null" : "collect before init, collect is not null" + collect.getClass().toString());
        Log.d("teest", "builder" + builder);
        CollectOptions options = builder.build();
        Log.d("teest", "options" + options);
        Collect.init(options);
//        Log.d("teest", "collect after init" + collect.getClass().toString());
        Log.d("teest", collect == null ? "collect after init, collect is null" : "collect after init, collect is not null" + collect.getClass().toString());
        collect = Collect.getInstance();
    }

    @Override
    @NonNull
    public String getName() {
        return NAME;
    }

    @ReactMethod
    public void setEventNameProperties(String eventName) {
        collect.setEventProperties(eventName);
    }

    @ReactMethod
    public void setEventProperties(String eventName, ReadableMap eventProp) {
        collect.setEventProperties(eventName, eventProp.toHashMap());
    }

    @ReactMethod
    public void setInstantEventNameProperties(String eventName) {
        collect.setInstantEventProperties(eventName);
    }

    @ReactMethod
    public void setInstantEventProperties(String eventName, ReadableMap eventProp) {
        collect.setInstantEventProperties(eventName, eventProp.toHashMap());
    }

    @ReactMethod
    public void setUserIdentities(ReadableMap userProp) {
        collect.setUserIdentities(userProp.toHashMap());
    }

    @ReactMethod
    public void setUserProperties(ReadableMap userProp) {
        collect.setUserProperties(userProp.toHashMap());
    }

    @ReactMethod
    public void setPageProperties(ReadableMap properties) {
        collect.setPageProperties(properties.toHashMap());
    }

    @ReactMethod
    public void unsetUserIdentities() {
        collect.unsetUserIdentities();
    }

    @ReactMethod
    public void deInitiate() {
        collect.pauseCollection();
    }

    @ReactMethod
    public void reInitialize() {
        collect.resumeCollection();
    }

    @ReactMethod
    public void setConsent(ReadableMap consent) {
        collect.setConsent(consent.toHashMap());
    }

    @ReactMethod
    public void addAskForConsentListener(Callback cb) {
        collect.listenToAskForConsent((data) -> cb.invoke());
    }

    @ReactMethod
    public void getZI(Callback cb) {
        String zi = collect.getZI();
        cb.invoke(zi);
    }

    @ReactMethod
    public void resetZI() {
        collect.resetZI();
    }

//    @ReactMethod
//    public void initialiseSDK(ReadableMap userProp) {
//        HashMap<String, Object> clientOptions = userProp.toHashMap();
//        if (clientOptions.get("logging") != null && clientOptions.get("logging") instanceof Boolean) {
//            builder = builder.enableLogging((Boolean) clientOptions.get("logging"));
//        }
//        if (clientOptions.get("batch_size") != null && !Objects.equals(clientOptions.get("batch_size"), "") && clientOptions.get("batch_size") instanceof Integer) {
//            builder = builder.uploadBatchSize((Integer) clientOptions.get("batch_size"));
//        }
//        if (clientOptions.get("optout") != null && clientOptions.get("optout")  instanceof Boolean) {
//            builder = builder.optOut((Boolean) clientOptions.get("optout"));
//        }
//        if (clientOptions.get("android_write_key") != null && !Objects.equals(clientOptions.get("write_key"), "") && clientOptions.get("write_key") instanceof String) {
//            builder = builder.credential((String) clientOptions.get("write_key"));
//        }
//        if (clientOptions.get("service_interval") != null && !Objects.equals(clientOptions.get("service_interval"), "") && clientOptions.get("service_interval") instanceof Integer)  {
//            builder = builder.serviceUploadInterval((Integer) clientOptions.get("service_interval"));
//        }
//        if (clientOptions.get("useConsent") != null && clientOptions.get("useConsent") instanceof Boolean) {
//            builder = builder.useConsent((Boolean) clientOptions.get("useConsent"));
//        }
//        if (clientOptions.get("maxCacheSize") != null && !Objects.equals(clientOptions.get("maxCacheSize"), "") && clientOptions.get("maxCacheSize") instanceof Integer) {
//            builder = builder.maxCacheSize((Integer) clientOptions.get("maxCacheSize"));
//        }
//        if (clientOptions.get("userCountry") != null && !Objects.equals(clientOptions.get("userCountry"), "") && clientOptions.get("userCountry") instanceof String) {
//            builder = builder.userCountry((String) clientOptions.get("userCountry"));
//        }
//        if (clientOptions.get("checkForCMP") != null && clientOptions.get("checkForCMP") instanceof Boolean) {
//            builder = builder.checkForCMP((Boolean) clientOptions.get("checkForCMP"));
//        }
//        if (clientOptions.get("purposesForTracking") != null && clientOptions.get("purposesForTracking") instanceof List) {
//            builder = builder.purposesForTracking((ArrayList<Integer>) clientOptions.get("purposesForTracking"));
//        }
//        if (clientOptions.get("purposesForIdentify") != null && clientOptions.get("purposesForIdentify") instanceof List) {
//            builder = builder.purposesForTracking((ArrayList<Integer>) clientOptions.get("purposesForIdentify"));
//        }
//        if (clientOptions.get("areIdentitiesHashed") != null && clientOptions.get("areIdentitiesHashed") instanceof Boolean) {
//            builder = builder.areIdentitiesHashed((Boolean) clientOptions.get("areIdentitiesHashed"));
//            if (clientOptions.get("hashIdentities") != null && clientOptions.get("hashIdentities") instanceof Boolean) {
//                builder = builder.hashIdentities((Boolean) clientOptions.get("hashIdentities"));
//            }
//        }
////        if (clientOptions.get("checkZeotapVendorConsent") != null && clientOptions.get("checkZeotapVendorConsent") instanceof Boolean) {
////            builder = builder.checkZeotapVendorConsent((Boolean) clientOptions.get("checkZeotapVendorConsent"));
////        }
////        Log.d("teest", "collect before init" + collect.getClass().toString());
//        Log.d("teest", collect == null ? "collect before init, collect is null" : "collect before init, collect is not null" + collect.getClass().toString());
//        Log.d("teest", "builder" + builder);
//        CollectOptions options = builder.build();
//        Log.d("teest", "options" + options);
//        Collect.init(options);
////        Log.d("teest", "collect after init" + collect.getClass().toString());
//        Log.d("teest", collect == null ? "collect after init, collect is null" : "collect after init, collect is not null" + collect.getClass().toString());
//    }
}

==> zeo-collect-0.2.5.tgz: package/android/src/main/java/com/zeocollect/ZeoCollectModule.java <==
package com.zeocollect;

import android.util.Log;

import androidx.annotation.NonNull;

import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.module.annotations.ReactModule;
import com.zeotap.collect.Collect;
import com.zeotap.collect.CollectOptions;

import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;

@ReactModule(name = ZeoCollectModule.NAME)
public class ZeoCollectModule extends ReactContextBaseJavaModule {
    public static final String NAME = "ZeoCollect";
    CollectOptions.Builder builder;
    Collect collect;
    ReactApplicationContext mReactContext;

    public ZeoCollectModule(ReactApplicationContext reactContext) {
        super(reactContext);
        mReactContext = reactContext;
    }

    @ReactMethod
    public void initalizeBySettingOptions(ReadableMap rawOptions) {
        builder = CollectOptions.builder(mReactContext);
        HashMap<String, Object> clientOptions = rawOptions.toHashMap();
        if (clientOptions.get("logging") != null && clientOptions.get("logging") instanceof Boolean) {
            builder = builder.enableLogging((Boolean) clientOptions.get("logging"));
        }
        if (clientOptions.get("batch_size") != null && !Objects.equals(clientOptions.get("batch_size"), "") && clientOptions.get("batch_size") instanceof Integer) {
            builder = builder.uploadBatchSize((Integer) clientOptions.get("batch_size"));
        }
        if (clientOptions.get("optout") != null && clientOptions.get("optout")  instanceof Boolean) {
            builder = builder.optOut((Boolean) clientOptions.get("optout"));
        }
        if (clientOptions.get("android_write_key") != null && !Objects.equals(clientOptions.get("write_key"), "") && clientOptions.get("write_key") instanceof String) {
            builder = builder.credential((String) clientOptions.get("write_key"));
        }
        if (clientOptions.get("service_interval") != null && !Objects.equals(clientOptions.get("service_interval"), "") && clientOptions.get("service_interval") instanceof Integer)  {
            builder = builder.serviceUploadInterval((Integer) clientOptions.get("service_interval"));
        }
        if (clientOptions.get("useConsent") != null && clientOptions.get("useConsent") instanceof Boolean) {
            builder = builder.useConsent((Boolean) clientOptions.get("useConsent"));
        }
        if (clientOptions.get("maxCacheSize") != null && !Objects.equals(clientOptions.get("maxCacheSize"), "") && clientOptions.get("maxCacheSize") instanceof Integer) {
            builder = builder.maxCacheSize((Integer) clientOptions.get("maxCacheSize"));
        }
        if (clientOptions.get("userCountry") != null && !Objects.equals(clientOptions.get("userCountry"), "") && clientOptions.get("userCountry") instanceof String) {
            builder = builder.userCountry((String) clientOptions.get("userCountry"));
        }
        if (clientOptions.get("checkForCMP") != null && clientOptions.get("checkForCMP") instanceof Boolean) {
            builder = builder.checkForCMP((Boolean) clientOptions.get("checkForCMP"));
        }
        if (clientOptions.get("purposesForTracking") != null && clientOptions.get("purposesForTracking") instanceof List) {
            builder = builder.purposesForTracking((ArrayList<Integer>) clientOptions.get("purposesForTracking"));
        }
        if (clientOptions.get("purposesForIdentify") != null && clientOptions.get("purposesForIdentify") instanceof List) {
            builder = builder.purposesForTracking((ArrayList<Integer>) clientOptions.get("purposesForIdentify"));
        }
        if (clientOptions.get("areIdentitiesHashed") != null && clientOptions.get("areIdentitiesHashed") instanceof Boolean) {
            builder = builder.areIdentitiesHashed((Boolean) clientOptions.get("areIdentitiesHashed"));
            if (clientOptions.get("hashIdentities") != null && clientOptions.get("hashIdentities") instanceof Boolean) {
                builder = builder.hashIdentities((Boolean) clientOptions.get("hashIdentities"));
            }
        }
//        if (clientOptions.get("checkZeotapVendorConsent") != null && clientOptions.get("checkZeotapVendorConsent") instanceof Boolean) {
//            builder = builder.checkZeotapVendorConsent((Boolean) clientOptions.get("checkZeotapVendorConsent"));
//        }
//        Log.d("teest", "collect before init" + collect.getClass().toString());
        Log.d("teest", builder == null ? "builder before init, collect is null" : "builder before init, builder is not null" + builder.getClass().toString());
        CollectOptions options = builder.build();
        Log.d("teest", builder == null ? "builder after init, builder is null" : "builder after init, builder is not null" + builder.getClass().toString());
        Log.d("teest", options == null ? "options before init, options is null" : "options before init, options is not null" + options.getClass().toString());
        Log.d("teest", "options" + options);
        Log.d("teest", "getOptions" + options.getOptions());
        Log.d("teest", "builder" + builder);
        Collect.init(options);
        Log.d("teest", options == null ? "options after init, options is null" : "options after init, options is not null" + options.getClass().toString());
        Log.d("teest", collect == null ? "collect before init, collect is null" : "collect before init, collect is not null" + collect.getClass().toString());
        collect = Collect.getInstance();
        Log.d("teest", collect == null ? "collect after init, collect is null" : "collect after init, collect is not null" + collect.getClass().toString());
    }

    @Override
    @NonNull
    public String getName() {
        return NAME;
    }

    @ReactMethod
    public void setEventNameProperties(String eventName) {
        Log.d("teest", collect == null ? "collect in setEventNameProperties, collect is null" : "collect in setEventNameProperties, collect is not null" + collect.getClass().toString());
        collect.setEventProperties(eventName);
    }

    @ReactMethod
    public void setEventProperties(String eventName, ReadableMap eventProp) {
        Log.d("teest", collect == null ? "collect in setEventProperties, collect is null" : "collect in setEventProperties, collect is not null" + collect.getClass().toString());
        collect.setEventProperties(eventName, eventProp.toHashMap());
    }

    @ReactMethod
    public void setInstantEventNameProperties(String eventName) {
        Log.d("teest", collect == null ? "collect in setInstantEventNameProperties, collect is null" : "collect in setInstantEventNameProperties, collect is not null" + collect.getClass().toString());
        collect.setInstantEventProperties(eventName);
    }

    @ReactMethod
    public void setInstantEventProperties(String eventName, ReadableMap eventProp) {
        Log.d("teest", collect == null ? "collect in setInstantEventProperties, collect is null" : "collect in setInstantEventProperties, collect is not null" + collect.getClass().toString());
        collect.setInstantEventProperties(eventName, eventProp.toHashMap());
    }

    @ReactMethod
    public void setUserIdentities(ReadableMap userProp) {
        collect.setUserIdentities(userProp.toHashMap());
    }

    @ReactMethod
    public void setUserProperties(ReadableMap userProp) {
        collect.setUserProperties(userProp.toHashMap());
    }

    @ReactMethod
    public void setPageProperties(ReadableMap properties) {
        Log.d("teest", collect == null ? "collect in setPageProperties, collect is null" : "collect in setPageProperties, collect is not null" + collect.getClass().toString());
        collect.setPageProperties(properties.toHashMap());
    }

    @ReactMethod
    public void unsetUserIdentities() {
        collect.unsetUserIdentities();
    }

    @ReactMethod
    public void deInitiate() {
        collect.pauseCollection();
    }

    @ReactMethod
    public void reInitialize() {
        collect.resumeCollection();
    }

    @ReactMethod
    public void setConsent(ReadableMap consent) {
        collect.setConsent(consent.toHashMap());
    }

    @ReactMethod
    public void addAskForConsentListener(Callback cb) {
        collect.listenToAskForConsent((data) -> cb.invoke());
    }

    @ReactMethod
    public void getZI(Callback cb) {
        String zi = collect.getZI();
        cb.invoke(zi);
    }

    @ReactMethod
    public void resetZI() {
        collect.resetZI();
    }

//    @ReactMethod
//    public void initialiseSDK(ReadableMap userProp) {
//        HashMap<String, Object> clientOptions = userProp.toHashMap();
//        if (clientOptions.get("logging") != null && clientOptions.get("logging") instanceof Boolean) {
//            builder = builder.enableLogging((Boolean) clientOptions.get("logging"));
//        }
//        if (clientOptions.get("batch_size") != null && !Objects.equals(clientOptions.get("batch_size"), "") && clientOptions.get("batch_size") instanceof Integer) {
//            builder = builder.uploadBatchSize((Integer) clientOptions.get("batch_size"));
//        }
//        if (clientOptions.get("optout") != null && clientOptions.get("optout")  instanceof Boolean) {
//            builder = builder.optOut((Boolean) clientOptions.get("optout"));
//        }
//        if (clientOptions.get("android_write_key") != null && !Objects.equals(clientOptions.get("write_key"), "") && clientOptions.get("write_key") instanceof String) {
//            builder = builder.credential((String) clientOptions.get("write_key"));
//        }
//        if (clientOptions.get("service_interval") != null && !Objects.equals(clientOptions.get("service_interval"), "") && clientOptions.get("service_interval") instanceof Integer)  {
//            builder = builder.serviceUploadInterval((Integer) clientOptions.get("service_interval"));
//        }
//        if (clientOptions.get("useConsent") != null && clientOptions.get("useConsent") instanceof Boolean) {
//            builder = builder.useConsent((Boolean) clientOptions.get("useConsent"));
//        }
//        if (clientOptions.get("maxCacheSize") != null && !Objects.equals(clientOptions.get("maxCacheSize"), "") && clientOptions.get("maxCacheSize") instanceof Integer) {
//            builder = builder.maxCacheSize((Integer) clientOptions.get("maxCacheSize"));
//        }
//        if (clientOptions.get("userCountry") != null && !Objects.equals(clientOptions.get("userCountry"), "") && clientOptions.get("userCountry") instanceof String) {
//            builder = builder.userCountry((String) clientOptions.get("userCountry"));
//        }
//        if (clientOptions.get("checkForCMP") != null && clientOptions.get("checkForCMP") instanceof Boolean) {
//            builder = builder.checkForCMP((Boolean) clientOptions.get("checkForCMP"));
//        }
//        if (clientOptions.get("purposesForTracking") != null && clientOptions.get("purposesForTracking") instanceof List) {
//            builder = builder.purposesForTracking((ArrayList<Integer>) clientOptions.get("purposesForTracking"));
//        }
//        if (clientOptions.get("purposesForIdentify") != null && clientOptions.get("purposesForIdentify") instanceof List) {
//            builder = builder.purposesForTracking((ArrayList<Integer>) clientOptions.get("purposesForIdentify"));
//        }
//        if (clientOptions.get("areIdentitiesHashed") != null && clientOptions.get("areIdentitiesHashed") instanceof Boolean) {
//            builder = builder.areIdentitiesHashed((Boolean) clientOptions.get("areIdentitiesHashed"));
//            if (clientOptions.get("hashIdentities") != null && clientOptions.get("hashIdentities") instanceof Boolean) {
//                builder = builder.hashIdentities((Boolean) clientOptions.get("hashIdentities"));
//            }
//        }
////        if (clientOptions.get("checkZeotapVendorConsent") != null && clientOptions.get("checkZeotapVendorConsent") instanceof Boolean) {
////            builder = builder.checkZeotapVendorConsent((Boolean) clientOptions.get("checkZeotapVendorConsent"));
////        }
////        Log.d("teest", "collect before init" + collect.getClass().toString());
//        Log.d("teest", collect == null ? "collect before init, collect is null" : "collect before init, collect is not null" + collect.getClass().toString());
//        Log.d("teest", "builder" + builder);
//        CollectOptions options = builder.build();
//        Log.d("teest", "options" + options);
//        Collect.init(options);
////        Log.d("teest", "collect after init" + collect.getClass().toString());
//        Log.d("teest", collect == null ? "collect after init, collect is null" : "collect after init, collect is not null" + collect.getClass().toString());
//    }
}
